@@ -1,4 +1,5 @@
 use anyhow::{anyhow, Result};
+#[cfg(feature = "http")]
 use curl::easy::Easy;
 use ethcontract_common::Address;
 use inflector::Inflector;
@@ -54,6 +55,7 @@ where
 }
 
 /// Performs an HTTP GET request and return the contents of the response.
+#[cfg(feature = "http")]
 pub fn http_get(url: &str) -> Result<String> {
     let mut buffer = Vec::new();
     let mut handle = Easy::new();
@@ -92,16 +94,18 @@ mod tests {
 
     #[test]
     fn parse_address_missing_prefix() {
-        if parse_address("0000000000000000000000000000000000000000").is_ok() {
-            panic!("parsing address not starting with 0x should fail");
-        }
+        assert!(
+            parse_address("0000000000000000000000000000000000000000").is_err(),
+            "parsing address not starting with 0x should fail"
+        );
     }
 
     #[test]
     fn parse_address_address_too_short() {
-        if parse_address("0x00000000000000").is_ok() {
-            panic!("parsing address not starting with 0x should fail");
-        }
+        assert!(
+            parse_address("0x00000000000000").is_err(),
+            "parsing address not starting with 0x should fail"
+        );
     }
 
     #[test]
